function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import uuid from 'uuid';
import ListItem from './ListItem';

var EditableList = function (_Component) {
    _inherits(EditableList, _Component);

    function EditableList() {
        _classCallCheck(this, EditableList);

        var _this = _possibleConstructorReturn(this, _Component.call(this));

        _this.state = { title: null, listItems: [{ itemContent: null, extraContent: true, id: uuid.v4() }] };
        return _this;
    }

    EditableList.prototype.componentDidMount = function componentDidMount() {
        var items = [];
        if (this.props.items) {
            items = this.props.items.map(function (currentItem) {
                return {
                    itemContent: currentItem,
                    extraContent: false,
                    id: uuid.v4()
                };
            });
        }

        items = [].concat(items, this.state.listItems);

        this.setState({ title: this.props.title, listItems: items });
        this.refs.title.textContent = this.props.title;
    };

    EditableList.prototype.render = function render() {
        var _this2 = this;

        return React.createElement(
            'div',
            null,
            React.createElement('h2', { contentEditable: true, ref: 'title', onKeyUp: function onKeyUp(event) {
                    return _this2.onTitleChange(event);
                } }),
            React.createElement(
                'div',
                { className: 'content-container' },
                this.renderListItems()
            )
        );
    };

    EditableList.prototype.renderListItems = function renderListItems() {
        var _this3 = this;

        return this.state.listItems.map(function (listItem) {
            return React.createElement(ListItem, { key: listItem.id, item: listItem,
                onKeyUp: _this3.onListItemKeyPress.bind(_this3),
                onRemove: _this3.onRemove.bind(_this3), onPaste: _this3.onPaste.bind(_this3),
                placeholder: _this3.props.itemPlaceholder, ref: listItem.id });
        });
    };

    EditableList.prototype.onTitleChange = function onTitleChange(event) {
        var _this4 = this;

        this.setState({ title: this.refs.title.textContent }, function () {
            return _this4.onChange();
        });
    };

    EditableList.prototype.onListItemKeyPress = function onListItemKeyPress(event, listItemId, content) {
        var _this5 = this;

        var listItemsTemp = Array.from(this.state.listItems);
        var index = listItemsTemp.findIndex(function (item) {
            return item.id === listItemId;
        });
        var currentItem = listItemsTemp[index];
        currentItem.itemContent = content;
        currentItem.extraContent = content ? false : currentItem.extraContent;
        this.setState({ listItems: listItemsTemp }, function () {
            if (!content) {
                _this5.onChange();
            }
        });

        if (content) {
            this.ensureExtraContent();
        }

        if (event.keyCode === 13) {
            if (!content) {
                // If no content was added then we don't want to create a new list item
                return;
            }

            // Finding the next sibling by looking at the next list item in the list
            // and getting its Id.
            var nextId = listItemsTemp[index + 1].id;
            this.refs[nextId].focus();
        }
    };

    EditableList.prototype.onRemove = function onRemove(listItemId) {
        var _this6 = this;

        var updatedItems = this.state.listItems.filter(function (item) {
            return item.id !== listItemId;
        });
        this.setState({ listItems: updatedItems }, function () {
            _this6.ensureExtraContent();
        });
    };

    EditableList.prototype.onPaste = function onPaste(listItemId, linesAdded) {
        var _this7 = this;

        var listItemsTemp = Array.from(this.state.listItems);
        var index = listItemsTemp.findIndex(function (item) {
            return item.id === listItemId;
        }) + 1;
        for (var i = 0; i < linesAdded.length; i++) {
            listItemsTemp.splice(index + 1, 0, { itemContent: linesAdded[i], id: uuid.v4() });
        }

        this.setState({ listItems: listItemsTemp }, function () {
            _this7.ensureExtraContent();
        });
    };

    EditableList.prototype.ensureExtraContent = function ensureExtraContent() {
        var callback = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : this.onChange.bind(this);

        var hasExtraContent = false;
        this.state.listItems.forEach(function (currentItem) {
            if (currentItem.extraContent) {
                hasExtraContent = true;
                callback();
                return;
            }
        });

        if (!hasExtraContent) {
            var listItemsTemp = Array.from(this.state.listItems);
            listItemsTemp.push({ itemContent: null, extraContent: true, id: uuid.v4() });
            this.setState({ listItems: listItemsTemp }, callback);
        }
    };

    EditableList.prototype.onChange = function onChange() {
        if (!this.props.onChange) {
            return;
        }

        var editableListContents = {};
        editableListContents.title = this.state.title;
        editableListContents.listItems = this.state.listItems.map(function (listItem) {
            return {
                id: listItem.id,
                text: listItem.itemContent
            };
        });

        this.props.onChange(editableListContents);
    };

    return EditableList;
}(Component);

export default EditableList;