'use strict';

exports.__esModule = true;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _fontawesomeSvgCore = require('@fortawesome/fontawesome-svg-core');

var _reactFontawesome = require('@fortawesome/react-fontawesome');

var _freeSolidSvgIcons = require('@fortawesome/free-solid-svg-icons');

require('../css/ListItem.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

_fontawesomeSvgCore.library.add(_freeSolidSvgIcons.faTimesCircle);

var ListItem = function (_Component) {
    _inherits(ListItem, _Component);

    function ListItem() {
        _classCallCheck(this, ListItem);

        // Creates a reference that is then defined in the parent div for this component.
        var _this = _possibleConstructorReturn(this, _Component.call(this));

        _this.ref = _react2.default.createRef();
        return _this;
    }

    ListItem.prototype.componentDidMount = function componentDidMount() {
        // The 'current' property of the ref gives us the DOM element tied to the reference, which
        // we then use to focus the element as soon as it is created.
        //this.ref.current.focus();

        this.ref.current.textContent = this.props.item.itemContent;
    };

    ListItem.prototype.render = function render() {
        var _this2 = this;

        return _react2.default.createElement(
            'div',
            { className: 'list-item-container' },
            _react2.default.createElement('div', { className: 'list-item', onKeyPress: function onKeyPress(event) {
                    return _this2.onKeyPress(event);
                }, onKeyUp: function onKeyUp(event) {
                    return _this2.onKeyUp(event);
                },
                ref: this.ref, contentEditable: true, placeholder: this.props.placeholder, onPaste: function onPaste(event) {
                    return _this2.handlePaste(event);
                } }),
            this.renderRemoveButton()
        );
    };

    ListItem.prototype.renderRemoveButton = function renderRemoveButton() {
        var _this3 = this;

        if (!this.props.item.extraContent) {
            return _react2.default.createElement(
                'div',
                { onClick: function onClick(event) {
                        return _this3.handleRemove(event);
                    }, className: 'remove-button', title: 'Remove' },
                _react2.default.createElement(_reactFontawesome.FontAwesomeIcon, { icon: 'times-circle' })
            );
        }
    };

    ListItem.prototype.handleRemove = function handleRemove(event) {
        event.preventDefault();
        this.props.onRemove(this.props.item.id);
    };

    ListItem.prototype.onKeyPress = function onKeyPress(event) {
        if (event.charCode === 13) {
            event.preventDefault();
        }
    };

    ListItem.prototype.onKeyUp = function onKeyUp(event) {
        var text = this.ref.current.textContent;
        this.props.onKeyUp(event, this.props.item.id, text);
    };

    ListItem.prototype.handlePaste = function handlePaste(event) {
        var clipboardData, pastedData;

        // Stop data actually being pasted into div
        event.stopPropagation();
        event.preventDefault();

        // Get pasted data via clipboard API
        clipboardData = event.clipboardData || window.clipboardData;
        pastedData = clipboardData.getData('Text');

        var linesAdded = pastedData.split('\n');
        // We only want to paste the first line and then let the List component handle the rest of them
        if (linesAdded.length === 0) {
            return;
        }

        var currentText = this.ref.current.textContent;
        currentText = currentText + linesAdded[0];
        this.ref.current.textContent = currentText;

        linesAdded.splice(0, 1);
        this.props.onPaste(this.props.item.id, linesAdded);
    };

    ListItem.prototype.focus = function focus() {
        this.ref.current.focus();
    };

    return ListItem;
}(_react.Component);

exports.default = ListItem;
module.exports = exports['default'];